DeveloperToolsLocalAuth class

Local Auth integration for developer_tools.

This class extends the core DeveloperToolsExtension so it can be passed to DeveloperTools.builder(extensions: [...]) in your MaterialApp.builder.

MaterialApp(
  builder: DeveloperTools.builder(
    extensions: const [DeveloperToolsLocalAuth()],
  ),
);
Inheritance

Constructors

DeveloperToolsLocalAuth({Key? key, String? packageName = 'local_auth', String? displayName = 'Local Auth'})
Creates a Local Auth developer tools extension.
const

Properties

displayName String?
Optional display name for this extension in the developer tools UI.
finalinherited
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
packageName String?
The name of the package that this extension is for.
finalinherited
pinned bool
When true, this extension's section is shown at the top of the developer tools overlay. Set by the developer for frequently used tools.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
Describes the part of the user interface represented by this widget.
inherited
buildEntries(BuildContext context) List<DeveloperToolEntry>
Returns the list of entries contributed by this extension.
override
createElement() StatelessElement
Creates a StatelessElement to manage this widget's location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
debugInfo(BuildContext context) Future<String?>
Returns debug information for this extension.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited